"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetVisorEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player visor updated.
 */
class PlayerSetVisorEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The visor that the player had before.
     */
    oldVisorId, 
    /**
     * The new visor that the player has.
     */
    newVisorId) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldVisorId = oldVisorId;
        this.newVisorId = newVisorId;
        this.eventName = "player.setvisor";
        this._alteredVisorId = newVisorId;
    }
    /**
     * The altered visor that the player will have set instead, if changed.
     */
    get alteredVisorId() {
        return this._alteredVisorId;
    }
    /**
     * Revert the player's visor back to their old visor.
     */
    revert() {
        this.setVisor(this.oldVisorId);
    }
    /**
     * Change the visor that the player had set.
     * @param visor The visor to set.
     */
    setVisor(visor) {
        this._alteredVisorId = visor;
    }
}
exports.PlayerSetVisorEvent = PlayerSetVisorEvent;
PlayerSetVisorEvent.eventName = "player.setvisor";
//# sourceMappingURL=SetVisor.js.map