"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactorConsoleAddEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player places their hand on a reactor console.
 */
class ReactorConsoleAddEvent extends events_1.RevertableEvent {
    constructor(room, reactor, message, 
    /**
     * The player that placed their hand on the console. Only available
     * if the client is the host.
     */
    player, 
    /**
     * The ID of the console that the player placed their hand on.
     */
    consoleId) {
        super();
        this.room = room;
        this.reactor = reactor;
        this.message = message;
        this.player = player;
        this.consoleId = consoleId;
        this.eventName = "reactor.consoles.add";
        this._alteredConsoleId = consoleId;
    }
    /**
     * The ID of the altered console that will be added instead, if changed.
     */
    get alteredConsoleId() {
        return this._alteredConsoleId;
    }
    /**
     * Change the console that the player placed their hand on.
     * @param consoleId The ID of the console to set.
     */
    setConsole(consoleId) {
        this._alteredConsoleId = consoleId;
    }
}
exports.ReactorConsoleAddEvent = ReactorConsoleAddEvent;
ReactorConsoleAddEvent.eventName = "reactor.consoles.add";
//# sourceMappingURL=ConsoleAdd.js.map